# Copyright (c) 2019 Capital Fund Management
# SPDX-License-Identifier: MIT

import numpy as np
import pandas as pd

import jupytab


def test_data_schema():
    arrays = [
        ['A', 'A',
         'a', 'a',
         0, 0,
         'a$_!#àz', 'a$_!#àz'
         ],
        ['A', 'A',
         0, 1,
         'z$_"_àéça"', 'z_èà[|]a',
         'ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789', 'abcdefghijklmnopqrstuvwxyz0123456789'
         ]
    ]
    tuples = list(zip(*arrays))
    index = pd.MultiIndex.from_tuples(tuples, names=['first', 'second'])
    complex_df = pd.DataFrame(np.random.randn(len(index), len(index)), index=index, columns=index)

    tables = jupytab.Tables()
    tables['complex_df_no_index_{}[]#!'] = \
        jupytab.DataFrameTable('A multi-index Dataframe ({}[]#!)',
                               dataframe=complex_df)
    tables['complex_df_with_index_{}[]#!'] = \
        jupytab.DataFrameTable('A multi-index Dataframe ({}[]#!)',
                               dataframe=complex_df,
                               include_index=True)

    schema = tables.schema()

    assert schema[0]['id'] == 'complex_df_no_index_{}[]#!'
    assert schema[0]['alias'] == 'A multi-index Dataframe ({}[]#!)'
    assert schema[1]['id'] == 'complex_df_with_index_{}[]#!'
    assert schema[1]['alias'] == 'A multi-index Dataframe ({}[]#!)'

    raw_output = '[{"id": "complex_df_no_index_{}[]#!", "alias": "A multi-index Dataframe ({}[]#!' \
                 ')", "columns": [{"id": "A_A_1", "dataType": "float"}, {"id": "A_A_2", "dataType' \
                 '": "float"}, {"id": "a_0", "dataType": "float"}, {"id": "a_1", "dataType": "flo' \
                 'at"}, {"id": "0_z____aeca_", "dataType": "float"}, {"id": "0_z_ea_a", "dataType' \
                 '": "float"}, {"id": "a___az_ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789", "dataType": ' \
                 '"float"}, {"id": "a___az_abcdefghijklmnopqrstuvwxyz0123456789", "dataType": "fl' \
                 'oat"}]}, {"id": "complex_df_with_index_{}[]#!", "alias": "A multi-index Datafra' \
                 'me ({}[]#!)", "columns": [{"id": "A_A_1", "dataType": "float"}, {"id": "A_A_2",' \
                 ' "dataType": "float"}, {"id": "a_0", "dataType": "float"}, {"id": "a_1", "dataT' \
                 'ype": "float"}, {"id": "0_z____aeca_", "dataType": "float"}, {"id": "0_z_ea_a",' \
                 ' "dataType": "float"}, {"id": "a___az_ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789", "d' \
                 'ataType": "float"}, {"id": "a___az_abcdefghijklmnopqrstuvwxyz0123456789", "data' \
                 'Type": "float"}]}]'

    raw_schema = tables.render_schema(do_print=False)

    assert raw_output == raw_schema



# Copyright (c) 2019 Capital Fund Management
# SPDX-License-Identifier: MIT

import os

import pandas as pd
import jupytab

THIS_DIR = os.path.abspath(os.path.dirname(__file__))
RESOURCES = os.path.join(THIS_DIR, 'resources')


def test_data_schema():
    crime_df = pd.read_csv(os.path.join(RESOURCES, 'sacramento_crime.csv'))
    realestate_df = pd.read_csv(os.path.join(RESOURCES, 'sacramento_realestate.csv'))

    tables = jupytab.Tables()
    tables['sacramento_crime'] = \
        jupytab.DataFrameTable('Sacramento Crime', dataframe=crime_df)
    tables['sacramento_realestate'] = \
        jupytab.DataFrameTable('Sacramento RealEstate', dataframe=realestate_df)

    schema = tables.schema()

    assert schema[0]['id'] == 'sacramento_crime'
    assert schema[0]['alias'] == 'Sacramento Crime'
    columns = schema[0]['columns']
    assert len(columns) == 9

    raw_output = '[{"id": "sacramento_crime", "alias": "Sacramento Crime", "columns": [{"id": "cdat\
etime", "dataType": "string"}, {"id": "address", "dataType": "string"}, {"id": "district", "dataTyp\
e": "int"}, {"id": "beat", "dataType": "string"}, {"id": "grid", "dataType": "int"}, {"id": "crimed\
escr", "dataType": "string"}, {"id": "ucr_ncic_code", "dataType": "int"}, {"id": "latitude", "dataT\
ype": "float"}, {"id": "longitude", "dataType": "float"}]}, {"id": "sacramento_realestate", "alias"\
: "Sacramento RealEstate", "columns": [{"id": "street", "dataType": "string"}, {"id": "city", "data\
Type": "string"}, {"id": "zip", "dataType": "int"}, {"id": "state", "dataType": "string"}, {"id": "\
beds", "dataType": "int"}, {"id": "baths", "dataType": "int"}, {"id": "sq__ft", "dataType": "int"},\
 {"id": "type", "dataType": "string"}, {"id": "sale_date", "dataType": "string"}, {"id": "price", "\
dataType": "int"}, {"id": "latitude", "dataType": "float"}, {"id": "longitude", "dataType": "float"\
}]}]'

    assert raw_output == tables.render_schema(do_print=False)


def test_clean_column_name():
    assert jupytab.DataFrameTable\
               .clean_column_name(['abéçpo$ù"', 0, 'AaZz_#"\\']) == "_abecpo_u_0_AaZz__"


def test_replace_duplicated_column_name():
    assert jupytab.DataFrameTable.replace_duplicated_column_name(['A', 'A', 'a', 'z', 'a', 'Y']) \
           == ['A_1', 'A_2', 'a_1', 'z', 'a_2', 'Y']



# Copyright (c) Capital Fund Management
# Distributed under the terms of the MIT License.

import os
from setuptools import setup, find_packages

with open(os.path.join(os.path.dirname(__file__), '..', 'VERSION')) as version_file:
    VERSION = version_file.read().strip()

README = """

Jupytab allows you to **explore in Tableau data which is generated
dynamically by a Jupyter Notebook**. You can thus create Tableau data
sources in a very flexible way using all the power of Python.
This is achieved by having Tableau access data through a **web
server created by Jupytab**.

This package is an helper package to split dependencies between
Jupytab server and your notebook. It only requires pandas.

The full documentation is available on the project's home page.
"""

# This call to setup() does all the work
setup(
    name="jupytab",
    version=VERSION,
    description="Jupytab package to be used in notebooks",
    long_description_content_type="text/markdown",
    long_description=README,
    url="https://github.com/CFMTech/Jupytab",
    author="Brian Tribondeau",
    author_email="brian.tribondeau@cfm.fr",
    license="MIT",
    keywords="jupytab jupyter notebook wdc tableau",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
    ],
    packages=find_packages(exclude=["*.tests", "*.tests.*"]),
    python_requires='>=3.6',
    include_package_data=True,
    install_requires=["pandas"],
    project_urls={
        "Bug Tracker": "https://github.com/CFMTech/Jupytab/issues",
        "Documentation": "https://github.com/CFMTech/Jupytab",
        "Source Code": "https://github.com/CFMTech/Jupytab"
    }
)
